To access a collection at the Oni provider, enter the collection ID in the provided field and click the "Retrieve collection information" button.

To find the collection ID visit the provider portal, view the page of the collection you want to access, and the collection ID will be the text labelled "@id". Ensure you copy the _text_ of the ID and not the link of the ID.
